

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">

<html xmlns="http://www.w3.org/1999/xhtml">
<head><title>
	Online Banking Ireland - Ireland's Retail Bank From Permanent TSB
</title><meta content="JavaScript" name="vs_defaultClientScript" /><meta content="http://schemas.microsoft.com/intellisense/ie5" name="vs_targetSchema" />		
	<script language="JavaScript" src="js/IndexCss.js"></script>
	<link rel="stylesheet" href="css/main.css" /><link type="text/css" href="css/main_1024.css" rel="stylesheet" />
	  
	<!--[if IE 6]>
	    <link rel="stylesheet" href="css/main_ie6_1024.css" />
    <![endif]-->
	
    


<meta http-equiv="refresh" content="600;url=DoLogOff.aspx">

<!--[if IE 7]>
    <style type="text/css">
        .transfereeList
        {
	        border-collapse:collapse;
        }
        .transfereeList td
        {
	        border-bottom: 1px solid #eeeeee; border-top: 1px solid #eeeeee; height: 44px;
        }
    </style>
<![endif]-->
</head>
<body>
    <form name="aspnetForm" method="post" action="TransfereeManage.aspx" id="aspnetForm">
<input type="hidden" name="__VIEWSTATE" id="__VIEWSTATE" value="" /="/"


<script src="/online/ScriptResource.axd?d=BzyBF3G2C357LsfwvhW7tt0g16frfubML4kfJdZu91RycyMjBy_--SVryBJfs47VT6mkT-jfWIB7vffKJbz5cnJcOkgi330RyQ5yUit1HSYsgVeIHlsjy934uOci4gs5-3mNRn9cfEsMwWEriG_QbxgveQ81&amp;t=ffffffff8dc250fc" type="text/javascript"></script>
<input type="hidden" name="__EVENTVALIDATION" id="__EVENTVALIDATION" value="" /="/"
	    <!--MAIN PAGE TABLE - SETS FIXED WIDTH - START-->
	    <div id="wrap_all">
	<div id="top">
		<img src="img/ptsb_logot44_wwq.gif" alt="Permanent TSB" class="l">
		<div class="r">
			<p>LoCall
				<span>1890 500 121</span>
				International
				<span>+353 1 212 4101</span></p>
			<p>Mon - Fri 8am - 10pm (Excl. bank hols.), Sat 10am - 2pm, or E-mail <a href="mailto:info@permanenttsb.ie">
					info@permanenttsb.ie</a></p>
			<p><br>
			</p>
			<table border="0">
				<tr>
					<td width="100%" align="center" bgcolor=white><font size="3" face="bold" color=#cc0033><b><span id="ctl00_lblLstLogin" class="text">Your last successful logon was on 01 January 1970 at 00:00</span></b></font></td>
				</tr>
			</table>
		</div>
	</div> <!-- e top -->
	<div class="clear"></div>
	<div id="mainmenu" align="center">
		<ul>
		</ul>
	</div> <!-- e mainmenu -->
	<div class="clear"></div>

        <div class="inside" id="main">
            
    <div id="leftmenu">
	<ul>
		<li class="heading">
		Your Account
		<li class="subheading">
		<li class="subheading">
		Account Details
		<li>
			<a href="Account.aspx" onmouseover="self.status='Account Summary'; return true" onmouseout="self.status=''; return true">
				Account Summary</a>
		<li class="subheading">
		Other
		<li class="btm">
			<a href="dologoff.aspx" onmouseover="self.status='Logoff'; return true" onmouseout="self.status=''; return true">
				Logoff</a></li>
	</ul>
	<div class="clear"></div>
</div> <!-- e leftmenu -->	        
            
    
    <div id="rightcol">
        <div class="main_center">
            <h2>Manage my Payments and Transfers</h2> 
            <div class="main_center_section">


                <div id="ctl00_cphBody_uPnlReference">
	
                    
                        <div>
                            <div class="flt_left">
                                <span class="flt_left">Which type of recipient would you like to view?</span>
                                <br />
                                <select name="ctl00$cphBody$ddlPaymentType" id="ctl00_cphBody_ddlPaymentType" class="transfereePaymentDdl">
		<option selected="selected" value="0">Utility</option>
		<option value="1">Third Party</option>
		<option value="2">Standing Order</option>
		<option value="3">Direct Debit</option>

	</select>
                                <div id="ctl00_cphBody_UpdateProgress1" style="display:none;">
		
                                        <img class="flt_left" alt="Loading..." src="img/main/icons/loading.gif" />
                                    
	</div>
                            </div>
                            <div class="flt_rght">
                                <input type="image" name="ctl00$cphBody$btnTransfereeLink" id="ctl00_cphBody_btnTransfereeLink" title="Click here to add a new payment or transfer" class="btnTransfereeLink" src="img/main/buttons/PaymentsAndTransfers/AddaNewPaymentOrTransfer.gif" alt="Add a new payee account" border="0" />
                            </div>
                        </div>
                
                        <div class="clear"></div>
                        <br />
                    
                        <div>

	</div>
                    
                        <div id="ctl00_cphBody_pnlNoUtilityStatement">
		
                            <span id="ctl00_cphBody_lblNoUtilityStatement"><b><font color="Red">THERE ARE CURRENTLY NO UTILITY BILL PAYMENTS ASSOCIATED WITH YOUR ACCOUNTS. CLICK ON THE BUTTON ABOVE TO SET-UP A NEW UTILITY BILL PAYMENT.</font></b></span>
                        
	</div>
                        
                        
                        
                    
</div>
            </div>     
        </div>               
    </div>

        </div>
    

<script type="text/javascript">
//<![CDATA[
Sys.Application.initialize();
//]]>
</script>
</form>    

    <link href="css/ui-lightness/jquery-ui-1.8.13.custom.css" rel="stylesheet" type="text/css" />	
    <script src="js/jquery-1.5.1.min.js" type="text/javascript"></script>
    <script src="js/jquery-ui-1.8.13.custom.min.js" type="text/javascript"></script>     
   
    <link rel="stylesheet" href="css/PaymentAndTransfer.css">
    
    <script src="js/OnlineOpen24.js" type="text/javascript"></script>    
    
    <!--[if IE]>
        <link rel="stylesheet" href="css/PaymentAndTransfer_IE.css">    
    <![endif]-->      
    <!-- Conditional Comments End -->       
    
    
    <script src="js/TransfereeManage.js" type="text/javascript"></script>   

    
    
        <div class="clear"></div>
<p class="print">To print this page use landscape settings for your printer</p>

<div class="clear"></div>
<div class="clear20"></div>
    
</body>
</html>


