
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN">
<HTML>
	<HEAD>
		<title>Online Banking Ireland - Ireland's Retail Bank From Permanent TSB</title>
		<meta name="vs_defaultClientScript" content="JavaScript">
		<meta name="vs_targetSchema" content="http://schemas.microsoft.com/intellisense/ie5">
		<script language="JavaScript" src="js/IndexCss.js"></script>
	</HEAD>
	<body bottomMargin="0" bgColor="white" leftMargin="0" topMargin="0" rightMargin="0">
		<form name="frmDoLogOff" method="post" action="DoLogOff.aspx?ref0" id="frmDoLogOff">
<input type="hidden" name="__VIEWSTATE" id="__VIEWSTATE" value="" />

<input type="hidden" name="__EVENTVALIDATION" id="__EVENTVALIDATION" value="" />
			<table cellSpacing="0" cellPadding="0" width="760" align="center" border="0">
				<tr>
					<td>
						<div id="wrap_all">
	<div id="top">
		<img src="img/ptsb_logot44_wwq.gif" alt="Permanent TSB" class="l">
		<div class="r">
			<p>LoCall
				<span>1890 500 121</span>
				International
				<span>+353 1 212 4101</span></p>
			<p>Mon - Fri 8am - 10pm (Excl. bank hols.), Sat 10am - 2pm, or E-mail <a href="mailto:info@permanenttsb.ie">
					info@permanenttsb.ie</a></p>
			<p><br>
			</p>
			<table border="0">
				<tr>
					<td width="100%" align="center" bgcolor=white><font size="3" face="bold" color=#cc0033><b><span id="lblLstLogin" class="text"></span></b></font></td>
				</tr>
			</table>
		</div>
	</div> <!-- e top -->
	<div class="clear"></div>
	<div id="mainmenu" align="center">
		<ul>
		</ul>
	</div> <!-- e mainmenu -->
	<div class="clear"></div>

						<div class="inside" id="main">
							<div id="NoLeft">
								<h4>OPEN24 - LOGGED OUT
								</h4>
								<p>&nbsp;</p>
								<P class="text" align="center"><STRONG>You are now logged off. Thank you for banking 
										with Open24.</STRONG></P>
								<p>&nbsp;</p>
								<table align="center">
									<tr>
										<td class="submit"><a id="lbtnContinue" tabindex="2" class="sub" href="javascript:__doPostBack('lbtnContinue','')">CONTINUE</a></td>
									</tr>
								</table>
								<p class="buttons2"></p>
							</div>
						</div> <!-- e main --></td>
				</tr>
			</table>
		</form>
	</body>
</HTML>
