

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">

<html xmlns="http://www.w3.org/1999/xhtml">
<head><title>
	Online Banking Ireland - Ireland's Retail Bank From Permanent TSB
</title><meta content="JavaScript" name="vs_defaultClientScript" /><meta content="http://schemas.microsoft.com/intellisense/ie5" name="vs_targetSchema" />		
	<script language="JavaScript" src="js/IndexCss.js"></script>
	<link rel="stylesheet" href="css/main.css" /><link type="text/css" href="css/main_1024.css" rel="stylesheet" />
	  
	<!--[if IE 6]>
	    <link rel="stylesheet" href="css/main_ie6_1024.css" />
    <![endif]-->
	
    


<meta http-equiv="refresh" content="600;url=DoLogOff.aspx">

<!--[if IE 7]>
    <style type="text/css">
        .main_center .sepaPayment {height:270px;}
        .paymentCategory label { margin-top: 4px; }
        .main_center_section hr { margin: 0px; display: block; clear: both; }
    </style>
<![endif]-->


</head>
<body>
    <form name="aspnetForm" method="post" action="PayAndTransfer.aspx" id="aspnetForm">
<input type="hidden" name="__VIEWSTATE" id="__VIEWSTATE" value="" /="/"


<script src="/online/ScriptResource.axd?d=BzyBF3G2C357LsfwvhW7tt0g16frfubML4kfJdZu91RycyMjBy_--SVryBJfs47VT6mkT-jfWIB7vffKJbz5cnJcOkgi330RyQ5yUit1HSYsgVeIHlsjy934uOci4gs5-3mNRn9cfEsMwWEriG_QbxgveQ81&amp;t=ffffffff8dc250fc" type="text/javascript"></script>
<input type="hidden" name="__EVENTVALIDATION" id="__EVENTVALIDATION" value="" /="/"
	    <!--MAIN PAGE TABLE - SETS FIXED WIDTH - START-->
	    <div id="wrap_all">
	<div id="top">
		<img src="img/ptsb_logot44_wwq.gif" alt="Permanent TSB" class="l">
		<div class="r">
			<p>LoCall
				<span>1890 500 121</span>
				International
				<span>+353 1 212 4101</span></p>
			<p>Mon - Fri 8am - 10pm (Excl. bank hols.), Sat 10am - 2pm, or E-mail <a href="mailto:info@permanenttsb.ie">
					info@permanenttsb.ie</a></p>
			<p><br>
			</p>
			<table border="0">
				<tr>
					<td width="100%" align="center" bgcolor=white><font size="3" face="bold" color=#cc0033><b><span id="ctl00_lblLstLogin" class="text">Your last successful logon was on 01 January 1970 at 00:00</span></b></font></td>
				</tr>
			</table>
		</div>
	</div> <!-- e top -->
	<div class="clear"></div>
	<div id="mainmenu" align="center">
		<ul>
		</ul>
	</div> <!-- e mainmenu -->
	<div class="clear"></div>

        <div class="inside" id="main">
            
    <div id="leftmenu">
	<ul>
		<li class="heading">
		Your Account
		<li class="subheading">
		<li class="subheading">
		Account Details
		<li>
			<a href="Account.aspx" onmouseover="self.status='Account Summary'; return true" onmouseout="self.status=''; return true">
				Account Summary</a>
		<li class="subheading">
		Other
		<li class="btm">
			<a href="dologoff.aspx" onmouseover="self.status='Logoff'; return true" onmouseout="self.status=''; return true">
				Logoff</a></li>
	</ul>
	<div class="clear"></div>
</div> <!-- e leftmenu -->	        
            
        
    
    <div id="rightcol">
        <div class="main_center">
            <div>
                <h2>Payments &amp; Transfers</h2>
                <br />                      
            </div>


            <div class="main_center_section">
                Transfer money between your accounts or pay money to somebody else’s account in Ireland or abroad. You can also pay your bills here.
                <br /><br /><hr />
            
                <!-- Start: Other FromAccounts Validators -->
            
                <span id="ctl00_cphBody_uPnlValidators">

                        <div style="font-weight:bold;margin:10px 10px 20px 10px">
                            <div></div>   
                            <div></div> 
                                                    
                            <div></div>                        
                            <div></div>                        

                            <div></div>
                            
                            <div></div>
                            
                          
                                                   
                            <div></div>                                                                    
                             
                            

                        </div>
                    </span>
                <!-- End: Other FromAccounts Validators -->
            
                <div id="ctl00_cphBody_uPnlPaymentsAndTransfers">
	
                   
                   <div class="paymentCategory">
                        <span id="ctl00_cphBody_rblPaymentCategory"><input id="ctl00_cphBody_rblPaymentCategory_0" type="radio" name="ctl00$cphBody$rblPaymentCategory" value="Transfer between my accounts" checked="checked" /><label for="ctl00_cphBody_rblPaymentCategory_0">Transfer between my accounts</label><input id="ctl00_cphBody_rblPaymentCategory_1" type="radio" name="ctl00$cphBody$rblPaymentCategory" value="Pay a bill" onclick="javascript:setTimeout('__doPostBack(\'ctl00$cphBody$rblPaymentCategory$1\',\'\')', 0)" /><label for="ctl00_cphBody_rblPaymentCategory_1">Pay a bill</label><input id="ctl00_cphBody_rblPaymentCategory_2" type="radio" name="ctl00$cphBody$rblPaymentCategory" value="Pay to other accounts (incl. international payments)" onclick="javascript:setTimeout('__doPostBack(\'ctl00$cphBody$rblPaymentCategory$2\',\'\')', 0)" /><label for="ctl00_cphBody_rblPaymentCategory_2">Pay to other accounts (incl. international payments)</label></span>
                   </div> 
                   
                   
                    <br /><br />
                    <div id="ctl00_cphBody_pnlPaymentsAndTransfers" class="paymentsAndTransfers">
		
                        <div class="sixtypixcels">
                            <span class="destination_account_box">
                                <div class="label_top">
                                    <label for="ctl00_cphBody_ddlDestinationAccount" id="ctl00_cphBody_lblDestinationAccount">Pay money to:</label>
                                </div>
                                    <select name="ctl00$cphBody$ddlDestinationAccount" id="ctl00_cphBody_ddlDestinationAccount" class="onChangeDestination">
			<option selected="selected" value="Please select">Please select</option>
			<option value="0">Account Type 0 - 9999</option>

		</select>
                                <div class="LiteralOr">
                                    or
                                </div>
                            </span>
                            
                            <span class="source_account_box">
                                <div class="label_top">
                                    <label for="ctl00_cphBody_ddlSourceAccount" id="ctl00_cphBody_lblSourceAccount">Use money from my:</label>
                                </div>
                                <select name="ctl00$cphBody$ddlSourceAccount" id="ctl00_cphBody_ddlSourceAccount" disabled="disabled" class="onChangeSource">
			<option selected="selected" value="Please select">Please select</option>
			<option value="0">Account Type 0 - 9999</option>

		</select>
                            </span>
                            <span class="amount_box" >
                                <div class="Amount_label">
                                    <label for="ctl00_cphBody_tbxAmount" id="ctl00_cphBody_lblAmount">Amount</label>
                                </div>
                                <span id="ctl00_cphBody_lblCurrency">€</span>
                                <input name="ctl00$cphBody$tbxAmount" type="text" maxlength="12" id="ctl00_cphBody_tbxAmount" size="10" autocomplete="off" />
                                <br/>
                                <div class="lbl_amount_margin">The maximum you can transfer is €100,000 per day.</div>
                            </span>
                            
                            <div class="button_margin">
                                <input type="image" name="ctl00$cphBody$btnPay" id="ctl00_cphBody_btnPay" title="Click here to pay" title="Click here to pay" src="img/main/buttons/Common/Pay.gif" alt="Click here to pay" onclick="javascript:WebForm_DoPostBackWithOptions(new WebForm_PostBackOptions(&quot;ctl00$cphBody$btnPay&quot;, &quot;&quot;, true, &quot;ValidationGroupPaymentTransfer&quot;, &quot;&quot;, false, false))" border="0" />
                            </div> 
                            
                        </div>
                                    
                    
	</div>                    
                
</div>
            
                <div id="ctl00_cphBody_uPnlPayeeAccountDetails">
	  
                
                

                                  
                    <div class="AddPayeeButton" >
                        <div style="padding:10px 0px 10px 0px">
                            <input type="image" name="ctl00$cphBody$btnAddAPayeeAccount" id="ctl00_cphBody_btnAddAPayeeAccount" title="Click here to add a new payment or transfer" title="Click here to add a new payee account" src="img/main/buttons/PaymentsAndTransfers/AddaNewPaymentOrTransfer.gif" alt="Click here to add a new payment or transfer" border="0" />
                        </div>
                        <div style="padding:10px 0px 10px 0px">
                            <a id="ctl00_cphBody_lbManageMyPayeeAccounts" class="onClickManageMyPayeeAccounts" href="javascript:__doPostBack('ctl00$cphBody$lbManageMyPayeeAccounts','')">Manage my payments and transfers</a>
                        </div>
                    </div> 
                     <br />                       
                    
                
</div> 
            
            </div> 
            
            
            <div class="small_box flt_left">
                    <div class="smallHeader">
                        Standing Orders
                        <br /><br />
                    </div>
                    <div class="body">
                        <p>An instruction that you give to the bank to make regular payments out of your account to another account. You decide how much and how often the money is to be paid from your account, e.g. paying money to your landlord.</p>
                        <br /><br />
                        <div class="buttonContainer">
                            <span style="float:left"><input type="image" name="ctl00$cphBody$btnViewStandingOrders" id="ctl00_cphBody_btnViewStandingOrders" title="Click here to view your standing orders" title="Click here to view or amend your standing orders" src="img/main/buttons/Common/ViewOrAmend.gif" alt="Click here to view your standing orders" border="0" /></span>
                            <span style="float:right"><input type="image" name="ctl00$cphBody$btnCreateAStandingOrder" id="ctl00_cphBody_btnCreateAStandingOrder" title="Click here to create a standing order" title="Click here to Create a standing order" src="img/main/buttons/PaymentsAndTransfers/StandingOrderCreate.gif" alt="Click here to create a standing order" border="0" /></span>
                        </div>                            
                    </div> 
                    <br />                 
                </div>                    
                <div class="small_box flt_rght">
                    <div class="smallHeader">
                        Direct Debits
                        <br /><br />
                    </div>
                    <div class="body">
                        <p>An instruction that you give to the bank that allows a company to collect money from your account, often used to pay utility or credit card bills. The amount can vary.</p>
                        <br /><br /><br/>
                        <div class="buttonContainer">
                            <input type="image" name="ctl00$cphBody$btnViewDirectDebits" id="ctl00_cphBody_btnViewDirectDebits" title="Click here to view your direct debits" title="Click here to view or amend your direct debits" src="img/main/buttons/Common/ViewOrAmend.gif" alt="Click here to view your direct debits" border="0" />
                        </div>
                    </div>   
                    <br />                       
                </div>
               
        </div>    
        
        
         
                
 
        
    </div>  

        </div>
    

<script type="text/javascript">
//<![CDATA[
Sys.Application.initialize();
//]]>
</script>
</form>    

    <link href="css/ui-lightness/jquery-ui-1.8.13.custom.css" rel="stylesheet" type="text/css" />	
    <script src="js/jquery-1.5.1.min.js" type="text/javascript"></script>
    <script src="js/jquery-ui-1.8.13.custom.min.js" type="text/javascript"></script>     
   
    <link rel="stylesheet" href="css/PaymentAndTransfer.css">
    
    <script src="js/OnlineOpen24.js" type="text/javascript"></script>    
    
    <!--[if IE]>
        <link rel="stylesheet" href="css/PaymentAndTransfer_IE.css">    
    <![endif]-->      
    <!-- Conditional Comments End -->       
    
    

    <script src="js/PayAndTransfer.js" type="text/javascript"></script>

    
    
        <div class="clear"></div>
<p class="print">To print this page use landscape settings for your printer</p>

<div class="clear"></div>
<div class="clear20"></div>
    
</body>
</html>


